@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2018-2019, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,12 +20,8 @@
 #ifndef CALAMARESAPPLICATION_H
 #define CALAMARESAPPLICATION_H
 
-#include "Typedefs.h"
-
 #include <QApplication>
 
-#define APP CalamaresApplication::instance()
-
 class CalamaresWindow;
 
 namespace Calamares
@@ -86,4 +82,4 @@ private:
     bool m_debugMode;
 };
 
-#endif //CALAMARESAPPLICATION_H
+#endif  // CALAMARESAPPLICATION_H
