@@ -21,21 +21,25 @@
 
 #include "Job.h"
 
+#include "modulesystem/InstanceKey.h"
+
 #include <QVariant>
 
 namespace CalamaresPython
 {
 class PythonJobInterface;
 class Helper;
-}
+}  // namespace CalamaresPython
 
-namespace Calamares {
+namespace Calamares
+{
 
 class PythonJob : public Job
 {
     Q_OBJECT
 public:
-    explicit PythonJob( const QString& scriptFile,
+    explicit PythonJob( const ModuleSystem::InstanceKey& instance,
+                        const QString& scriptFile,
                         const QString& workingPath,
                         const QVariantMap& moduleConfiguration = QVariantMap(),
                         QObject* parent = nullptr );
@@ -45,6 +49,8 @@ public:
     QString prettyStatusMessage() const override;
     JobResult exec() override;
 
+    virtual qreal getJobWeight() const override;
+
 private:
     friend class CalamaresPython::Helper;
     friend class CalamaresPython::PythonJobInterface;
@@ -55,8 +61,9 @@ private:
     QString m_workingPath;
     QString m_description;
     QVariantMap m_configurationMap;
+    qreal m_weight;
 };
 
-} // namespace Calamares
+}  // namespace Calamares
 
-#endif // CALAMARES_PYTHONJOB_H
+#endif  // CALAMARES_PYTHONJOB_H
