@@ -20,8 +20,8 @@
 #include "PythonJobApi.h"
 
 #include "PythonHelper.h"
-#include "utils/Logger.h"
 #include "utils/CalamaresUtilsSystem.h"
+#include "utils/Logger.h"
 #include "utils/String.h"
 
 #include "GlobalStorage.h"
@@ -32,23 +32,32 @@
 #include <QStandardPaths>
 
 #undef slots
+#include "utils/boost-warnings.h"
 #include <boost/python.hpp>
 
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+
 namespace bp = boost::python;
 
 static int
 _handle_check_target_env_call_error( const CalamaresUtils::ProcessResult& ec, const QString& cmd )
 {
     if ( !ec.first )
+    {
         return ec.first;
+    }
 
     QString raise = QString( "import subprocess\n"
                              "e = subprocess.CalledProcessError(%1,\"%2\")\n" )
-                    .arg( ec.first )
-                    .arg( cmd );
+                        .arg( ec.first )
+                        .arg( cmd );
     if ( !ec.second.isEmpty() )
-        raise.append( QStringLiteral("e.output = \"\"\"%1\"\"\"\n").arg( ec.second ) );
-    raise.append("raise e");
+    {
+        raise.append( QStringLiteral( "e.output = \"\"\"%1\"\"\"\n" ).arg( ec.second ) );
+    }
+    raise.append( "raise e" );
     bp::exec( raise.toStdString().c_str() );
     bp::throw_error_already_set();
     return ec.first;
@@ -63,11 +72,10 @@ mount( const std::string& device_path,
        const std::string& filesystem_name,
        const std::string& options )
 {
-    return CalamaresUtils::System::instance()->
-           mount( QString::fromStdString( device_path ),
-                  QString::fromStdString( mount_point ),
-                  QString::fromStdString( filesystem_name ),
-                  QString::fromStdString( options ) );
+    return CalamaresUtils::System::instance()->mount( QString::fromStdString( device_path ),
+                                                      QString::fromStdString( mount_point ),
+                                                      QString::fromStdString( filesystem_name ),
+                                                      QString::fromStdString( options ) );
 }
 
 
@@ -77,64 +85,50 @@ _bp_list_to_qstringlist( const bp::list& args )
     QStringList list;
     for ( int i = 0; i < bp::len( args ); ++i )
     {
-        list.append( QString::fromStdString(
-                         bp::extract< std::string >( args[ i ] ) ) );
+        list.append( QString::fromStdString( bp::extract< std::string >( args[ i ] ) ) );
     }
     return list;
 }
 
 static inline CalamaresUtils::ProcessResult
-_target_env_command(
-    const QStringList& args,
-    const std::string& stdin,
-    int timeout )
+_target_env_command( const QStringList& args, const std::string& stdin, int timeout )
 {
-    return CalamaresUtils::System::instance()->
-        targetEnvCommand( args,
-                          QString(),
-                          QString::fromStdString( stdin ),
-                          timeout );
+    // Since Python doesn't give us the type system for distinguishing
+    // seconds from other integral types, massage to seconds here.
+    return CalamaresUtils::System::instance()->targetEnvCommand(
+        args, QString(), QString::fromStdString( stdin ), std::chrono::seconds( timeout ) );
 }
 
 int
-target_env_call( const std::string& command,
-                 const std::string& stdin,
-                 int timeout )
+target_env_call( const std::string& command, const std::string& stdin, int timeout )
 {
-    return _target_env_command(
-        QStringList{ QString::fromStdString( command ) }, stdin, timeout ).first;
+    return _target_env_command( QStringList { QString::fromStdString( command ) }, stdin, timeout ).first;
 }
 
 
 int
-target_env_call( const bp::list& args,
-                 const std::string& stdin,
-                 int timeout )
+target_env_call( const bp::list& args, const std::string& stdin, int timeout )
 {
-    return _target_env_command(
-        _bp_list_to_qstringlist( args ), stdin, timeout ).first;
+    return _target_env_command( _bp_list_to_qstringlist( args ), stdin, timeout ).first;
 }
 
 
 int
-check_target_env_call( const std::string& command,
-                       const std::string& stdin,
-                       int timeout )
+check_target_env_call( const std::string& command, const std::string& stdin, int timeout )
 {
-    auto ec = _target_env_command(
-        QStringList{ QString::fromStdString( command ) }, stdin, timeout );
+    auto ec = _target_env_command( QStringList { QString::fromStdString( command ) }, stdin, timeout );
     return _handle_check_target_env_call_error( ec, QString::fromStdString( command ) );
 }
 
 
 int
-check_target_env_call( const bp::list& args,
-                       const std::string& stdin,
-                       int timeout )
+check_target_env_call( const bp::list& args, const std::string& stdin, int timeout )
 {
     auto ec = _target_env_command( _bp_list_to_qstringlist( args ), stdin, timeout );
     if ( !ec.first )
+    {
         return ec.first;
+    }
 
     QStringList failedCmdList = _bp_list_to_qstringlist( args );
     return _handle_check_target_env_call_error( ec, failedCmdList.join( ' ' ) );
@@ -142,25 +136,19 @@ check_target_env_call( const bp::list& args,
 
 
 std::string
-check_target_env_output( const std::string& command,
-                         const std::string& stdin,
-                         int timeout )
+check_target_env_output( const std::string& command, const std::string& stdin, int timeout )
 {
-    auto ec = _target_env_command(
-        QStringList{ QString::fromStdString( command ) }, stdin, timeout );
+    auto ec = _target_env_command( QStringList { QString::fromStdString( command ) }, stdin, timeout );
     _handle_check_target_env_call_error( ec, QString::fromStdString( command ) );
     return ec.second.toStdString();
 }
 
 
 std::string
-check_target_env_output( const bp::list& args,
-                         const std::string& stdin,
-                         int timeout )
+check_target_env_output( const bp::list& args, const std::string& stdin, int timeout )
 {
     QStringList list = _bp_list_to_qstringlist( args );
-    auto ec = _target_env_command(
-        list, stdin, timeout );
+    auto ec = _target_env_command( list, stdin, timeout );
     _handle_check_target_env_call_error( ec, list.join( ' ' ) );
     return ec.second.toStdString();
 }
@@ -192,7 +180,9 @@ void
 PythonJobInterface::setprogress( qreal progress )
 {
     if ( progress >= 0 && progress <= 1 )
+    {
         m_parent->emitProgress( progress );
+    }
 }
 
 
@@ -214,7 +204,8 @@ _gettext_languages()
     //    own GlobalStoragePythonWrapper, which then holds a
     //    GlobalStorage object for all of Python.
     Calamares::JobQueue* jq = Calamares::JobQueue::instance();
-    Calamares::GlobalStorage* gs = jq ? jq->globalStorage() : CalamaresPython::GlobalStoragePythonWrapper::globalStorageInstance();
+    Calamares::GlobalStorage* gs
+        = jq ? jq->globalStorage() : CalamaresPython::GlobalStoragePythonWrapper::globalStorageInstance();
 
     QVariant localeConf_ = gs->value( "localeConf" );
     if ( localeConf_.canConvert< QVariantMap >() )
@@ -244,7 +235,9 @@ gettext_languages()
 {
     bp::list pyList;
     for ( auto lang : _gettext_languages() )
+    {
         pyList.append( lang.toStdString() );
+    }
     return pyList;
 }
 
@@ -255,7 +248,9 @@ _add_localedirs( QStringList& pathList, const QString& candidate )
     {
         pathList.prepend( candidate );
         if ( QDir( candidate ).cd( "lang" ) )
+        {
             pathList.prepend( candidate + "/lang" );
+        }
     }
 }
 
@@ -264,16 +259,19 @@ gettext_path()
 {
     // TODO: distinguish between -d runs and normal runs
     // TODO: can we detect DESTDIR-installs?
-    QStringList candidatePaths = QStandardPaths::locateAll( QStandardPaths::GenericDataLocation, "locale", QStandardPaths::LocateDirectory );
+    QStringList candidatePaths
+        = QStandardPaths::locateAll( QStandardPaths::GenericDataLocation, "locale", QStandardPaths::LocateDirectory );
     QString extra = QCoreApplication::applicationDirPath();
-    _add_localedirs( candidatePaths, extra ); // Often /usr/local/bin
+    _add_localedirs( candidatePaths, extra );  // Often /usr/local/bin
     if ( !extra.isEmpty() )
     {
         QDir d( extra );
-        if ( d.cd( "../share/locale" ) ) // Often /usr/local/bin/../share/locale -> /usr/local/share/locale
+        if ( d.cd( "../share/locale" ) )  // Often /usr/local/bin/../share/locale -> /usr/local/share/locale
+        {
             _add_localedirs( candidatePaths, d.canonicalPath() );
+        }
     }
-    _add_localedirs( candidatePaths, QDir().canonicalPath() ); // .
+    _add_localedirs( candidatePaths, QDir().canonicalPath() );  // .
 
     cDebug() << "Determining gettext path from" << candidatePaths;
 
@@ -294,4 +292,4 @@ gettext_path()
 }
 
 
-}
+}  // namespace CalamaresPython
