@@ -91,17 +91,16 @@ ModuleManager::doInit()
                 bool success = currentDir.cd( subdir );
                 if ( success )
                 {
+                    static const char bad_descriptor[] = "ModuleManager potential module descriptor is bad";
                     QFileInfo descriptorFileInfo( currentDir.absoluteFilePath( QLatin1String( "module.desc" ) ) );
                     if ( !descriptorFileInfo.exists() )
                     {
-                        cDebug() << "ModuleManager expected descriptor is missing:"
-                                 << descriptorFileInfo.absoluteFilePath();
+                        cDebug() << bad_descriptor << descriptorFileInfo.absoluteFilePath() << "(missing)";
                         continue;
                     }
                     if ( !descriptorFileInfo.isReadable() )
                     {
-                        cDebug() << "ModuleManager descriptor file is unreadable:"
-                                 << descriptorFileInfo.absoluteFilePath();
+                        cDebug() << bad_descriptor << descriptorFileInfo.absoluteFilePath() << "(unreadable)";
                         continue;
                     }
 
@@ -109,7 +108,7 @@ ModuleManager::doInit()
                     QVariantMap moduleDescriptorMap = CalamaresUtils::loadYaml( descriptorFileInfo, &ok );
                     QString moduleName = ok ? moduleDescriptorMap.value( "name" ).toString() : QString();
 
-                    if ( ok && ( moduleName == currentDir.dirName() )
+                    if ( ok && !moduleName.isEmpty() && ( moduleName == currentDir.dirName() )
                          && !m_availableDescriptorsByModuleName.contains( moduleName ) )
                     {
                         m_availableDescriptorsByModuleName.insert( moduleName, moduleDescriptorMap );
@@ -128,25 +127,22 @@ ModuleManager::doInit()
             cDebug() << "ModuleManager module search path does not exist:" << path;
         }
     }
-    // At this point m_availableModules is filled with whatever was found in the
-    // search paths.
+    // At this point m_availableDescriptorsByModuleName is filled with
+    // the modules that were found in the search paths.
+    cDebug() << "Found" << m_availableDescriptorsByModuleName.count() << "modules"
+             << m_moduleDirectoriesByModuleName.count() << "names";
     emit initDone();
 }
 
 
-QStringList
+QList< ModuleSystem::InstanceKey >
 ModuleManager::loadedInstanceKeys()
 {
-    QStringList l;
-    for ( const auto& m : m_loadedModulesByInstanceKey.keys() )
-    {
-        l << m.toString();
-    }
-    return l;
+    return m_loadedModulesByInstanceKey.keys();
 }
 
 
-QVariantMap
+Calamares::ModuleSystem::Descriptor
 ModuleManager::moduleDescriptor( const QString& name )
 {
     return m_availableDescriptorsByModuleName.value( name );
@@ -178,15 +174,54 @@ findCustomInstance( const Settings::InstanceDescriptionList& customInstances, co
     return -1;
 }
 
+/** @brief Returns the config file name for the fiven @p instanceKey
+ *
+ * Custom instances have custom config files, non-custom ones
+ * have a <modulename>.conf file. Returns an empty QString on
+ * errors.
+ */
+static QString
+getConfigFileName( const Settings::InstanceDescriptionList& customInstances,
+                   const ModuleSystem::InstanceKey& instanceKey,
+                   const ModuleSystem::Descriptor& descriptor )
+{
+    if ( instanceKey.isCustom() )
+    {
+        int found = findCustomInstance( customInstances, instanceKey );
+
+        if ( found < 0 )
+        {
+            // This should already have been checked and failed the module already
+            return QString();
+        }
+
+        return customInstances[ found ].value( "config" );
+    }
+    else
+    {
+        if ( descriptor.value( "noconfig", false ).toBool() )
+        {
+            // Explicitly set to no-configuration. This doesn't apply
+            // to custom instances (above) since the only reason to
+            // **have** a custom instance is to specify a different
+            // config file for more than one module.
+            return QString();
+        }
+        return QString( "%1.conf" ).arg( instanceKey.module() );
+    }
+}
 
 void
 ModuleManager::loadModules()
 {
-    QStringList failedModules = checkDependencies();
+    if ( checkDependencies() )
+    {
+        cWarning() << "Some installed modules have unmet dependencies.";
+    }
     Settings::InstanceDescriptionList customInstances = Settings::instance()->customModuleInstances();
 
-    const auto modulesSequence
-        = failedModules.isEmpty() ? Settings::instance()->modulesSequence() : Settings::ModuleSequence();
+    QStringList failedModules;
+    const auto modulesSequence = Settings::instance()->modulesSequence();
     for ( const auto& modulePhase : modulesSequence )
     {
         ModuleSystem::Action currentAction = modulePhase.first;
@@ -200,38 +235,29 @@ ModuleManager::loadModules()
                 failedModules.append( moduleEntry );
                 continue;
             }
-
-
-            if ( !m_availableDescriptorsByModuleName.contains( instanceKey.module() )
-                    || m_availableDescriptorsByModuleName.value( instanceKey.module() ).isEmpty() )
-            {
-                cError() << "Module" << instanceKey.toString() << "not found in module search paths."
-                            << Logger::DebugList( m_paths );
-                failedModules.append( instanceKey.toString() );
-                continue;
-            }
-
-            QString configFileName;
             if ( instanceKey.isCustom() )
             {
                 int found = findCustomInstance( customInstances, instanceKey );
-
-                if ( found > -1 )
-                {
-                    configFileName = customInstances[ found ].value( "config" );
-                }
-                else  //ought to be a custom instance, but cannot find instance entry
+                if ( found < 0 )
                 {
                     cError() << "Custom instance" << moduleEntry << "not found in custom instances section.";
                     failedModules.append( moduleEntry );
                     continue;
                 }
             }
-            else
+
+            ModuleSystem::Descriptor descriptor
+                = m_availableDescriptorsByModuleName.value( instanceKey.module(), ModuleSystem::Descriptor() );
+            if ( descriptor.isEmpty() )
             {
-                configFileName = QString( "%1.conf" ).arg( instanceKey.module() );
+                cError() << "Module" << instanceKey.toString() << "not found in module search paths."
+                         << Logger::DebugList( m_paths );
+                failedModules.append( instanceKey.toString() );
+                continue;
             }
 
+            QString configFileName = getConfigFileName( customInstances, instanceKey, descriptor );
+
             // So now we can assume that the module entry is at least valid,
             // that we have a descriptor on hand (and therefore that the
             // module exists), and that the instance is either default or
@@ -240,31 +266,38 @@ ModuleManager::loadModules()
             // exists and is valid, but that's the only thing that could fail
             // from this point on. -- Teo 8/2015
             Module* thisModule = m_loadedModulesByInstanceKey.value( instanceKey, nullptr );
-            if ( thisModule && !thisModule->isLoaded() )
+            if ( thisModule )
             {
-                cError() << "Module" << instanceKey.toString() << "exists but not loaded.";
-                failedModules.append( instanceKey.toString() );
-                continue;
-            }
-
-            if ( thisModule && thisModule->isLoaded() )
-            {
-                cDebug() << "Module" << instanceKey.toString() << "already loaded.";
+                if ( thisModule->isLoaded() )
+                {
+                    // It's been listed before, don't bother loading again.
+                    // This can happen for a module listed twice (e.g. with custom instances)
+                    cDebug() << "Module" << instanceKey.toString() << "already loaded.";
+                }
+                else
+                {
+                    // An attempt was made, earlier, and that failed.
+                    // This can happen for a module listed twice (e.g. with custom instances)
+                    cError() << "Module" << instanceKey.toString() << "exists but not loaded.";
+                    failedModules.append( instanceKey.toString() );
+                    continue;
+                }
             }
             else
             {
-                thisModule = Module::fromDescriptor( m_availableDescriptorsByModuleName.value( instanceKey.module() ),
-                                                        instanceKey.id(),
-                                                        configFileName,
-                                                        m_moduleDirectoriesByModuleName.value( instanceKey.module() ) );
+                thisModule = Module::fromDescriptor( descriptor,
+                                                     instanceKey.id(),
+                                                     configFileName,
+                                                     m_moduleDirectoriesByModuleName.value( instanceKey.module() ) );
                 if ( !thisModule )
                 {
-                    cError() << "Module" << instanceKey.toString() << "cannot be created from descriptor" << configFileName;
+                    cError() << "Module" << instanceKey.toString() << "cannot be created from descriptor"
+                             << configFileName;
                     failedModules.append( instanceKey.toString() );
                     continue;
                 }
 
-                if ( !checkDependencies( *thisModule ) )
+                if ( !checkModuleDependencies( *thisModule ) )
                 {
                     // Error message is already printed
                     failedModules.append( instanceKey.toString() );
@@ -345,10 +378,10 @@ missingRequiredModules( const QStringList& required, const QMap< QString, QVaria
     return l;
 }
 
-QStringList
+size_t
 ModuleManager::checkDependencies()
 {
-    QStringList failed;
+    size_t numberRemoved = 0;
     bool somethingWasRemovedBecauseOfUnmetDependencies = false;
 
     // This goes through the map of available modules, and deletes those whose
@@ -367,19 +400,18 @@ ModuleManager::checkDependencies()
                 QString moduleName = it->value( "name" ).toString();
                 somethingWasRemovedBecauseOfUnmetDependencies = true;
                 m_availableDescriptorsByModuleName.erase( it );
-                failed << moduleName;
-                cWarning() << "Module" << moduleName << "requires modules" << Logger::DebugList( unmet );
-                cWarning() << Logger::SubEntry << "but these are not available (listed in settings, or installed).";
+                numberRemoved++;
+                cWarning() << "Module" << moduleName << "requires missing modules" << Logger::DebugList( unmet );
                 break;
             }
         }
     } while ( somethingWasRemovedBecauseOfUnmetDependencies );
 
-    return failed;
+    return numberRemoved;
 }
 
 bool
-ModuleManager::checkDependencies( const Module& m )
+ModuleManager::checkModuleDependencies( const Module& m )
 {
     bool allRequirementsFound = true;
     QStringList requiredModules
