@@ -462,7 +462,7 @@ ChoicePage::applyActionChoice( ChoicePage::InstallChoice choice )
                 gs->value( "defaultFileSystemType" ).toString(),
                 m_encryptWidget->passphrase(),
                 gs->value( "efiSystemPartition" ).toString(),
-                CalamaresUtils::GiBtoBytes( gs->value( "requiredStorageGB" ).toDouble() ),
+                CalamaresUtils::GiBtoBytes( gs->value( "requiredStorageGiB" ).toDouble() ),
                 m_eraseSwapChoice
             };
 
@@ -560,11 +560,10 @@ ChoicePage::doAlongsideSetupSplitter( const QModelIndex& current,
 
     double requiredStorageGB = Calamares::JobQueue::instance()
                                     ->globalStorage()
-                                    ->value( "requiredStorageGB" )
+                                    ->value( "requiredStorageGiB" )
                                     .toDouble();
 
-    // TODO: make this consistent
-    qint64 requiredStorageB = qRound64( requiredStorageGB + 0.1 + 2.0 ) * 1024 * 1024 * 1024;
+    qint64 requiredStorageB = CalamaresUtils::GiBtoBytes( requiredStorageGB + 0.1 + 2.0 );
 
     m_afterPartitionSplitterWidget->setSplitPartition(
                 part->partitionPath(),
@@ -961,19 +960,18 @@ ChoicePage::updateActionChoicePreview( ChoicePage::InstallChoice choice )
             QLabel* sizeLabel = new QLabel( m_previewAfterFrame );
             layout->addWidget( sizeLabel );
             sizeLabel->setWordWrap( true );
-            connect( m_afterPartitionSplitterWidget, &PartitionSplitterWidget::partitionResized,
-                     this, [ this, sizeLabel ]( const QString& path,
-                                                qint64 size,
-                                                qint64 sizeNext )
-            {
-                Q_UNUSED( path )
-                sizeLabel->setText( tr( "%1 will be shrunk to %2MB and a new "
-                                        "%3MB partition will be created for %4." )
-                                    .arg( m_beforePartitionBarsView->selectionModel()->currentIndex().data().toString() )
-                                    .arg( size / ( 1024 * 1024 ) )
-                                    .arg( sizeNext / ( 1024 * 1024 ) )
-                                    .arg( *Calamares::Branding::ShortProductName ) );
-            } );
+            connect( m_afterPartitionSplitterWidget, &PartitionSplitterWidget::partitionResized, this,
+                [ this, sizeLabel ]( const QString& path, qint64 size, qint64 sizeNext )
+                {
+                    Q_UNUSED( path )
+                    sizeLabel->setText( tr( "%1 will be shrunk to %2MiB and a new "
+                                            "%3MiB partition will be created for %4." )
+                                        .arg( m_beforePartitionBarsView->selectionModel()->currentIndex().data().toString() )
+                                        .arg( CalamaresUtils::BytesToMiB( size ) )
+                                        .arg( CalamaresUtils::BytesToMiB( sizeNext ) )
+                                        .arg( *Calamares::Branding::ShortProductName ) );
+                }
+            );
 
             m_previewAfterFrame->show();
             m_previewAfterLabel->show();
@@ -1026,18 +1024,25 @@ ChoicePage::updateActionChoicePreview( ChoicePage::InstallChoice choice )
                 eraseBootloaderLabel->setText( tr( "Boot loader location:" ) );
 
                 m_bootloaderComboBox = createBootloaderComboBox( eraseWidget );
-                connect( m_core, &PartitionCoreModule::deviceReverted,
-                         this, [ this ]( Device* dev )
-                {
-                    Q_UNUSED( dev )
-                    if ( !m_bootloaderComboBox.isNull() )
+                connect( m_core->bootLoaderModel(), &QAbstractItemModel::modelReset,
+                    [ this ]()
                     {
-                        if ( m_bootloaderComboBox->model() != m_core->bootLoaderModel() )
-                            m_bootloaderComboBox->setModel( m_core->bootLoaderModel() );
-
-                        m_bootloaderComboBox->setCurrentIndex( m_lastSelectedDeviceIndex );
+                        if ( !m_bootloaderComboBox.isNull() )
+                            Calamares::restoreSelectedBootLoader( *m_bootloaderComboBox, m_core->bootLoaderInstallPath() );
                     }
-                }, Qt::QueuedConnection );
+                );
+                connect( m_core, &PartitionCoreModule::deviceReverted, this,
+                    [ this ]( Device* dev )
+                    {
+                        Q_UNUSED( dev )
+                        if ( !m_bootloaderComboBox.isNull() )
+                        {
+                            if ( m_bootloaderComboBox->model() != m_core->bootLoaderModel() )
+                                m_bootloaderComboBox->setModel( m_core->bootLoaderModel() );
+
+                            m_bootloaderComboBox->setCurrentIndex( m_lastSelectedDeviceIndex );
+                        }
+                    }, Qt::QueuedConnection );
                 // ^ Must be Queued so it's sure to run when the widget is already visible.
 
                 eraseLayout->addWidget( m_bootloaderComboBox );
