@@ -41,7 +41,7 @@ CreatePartitionJob::CreatePartitionJob( Device* device, Partition* partition )
 QString
 CreatePartitionJob::prettyName() const
 {
-    return tr( "Create new %2MB partition on %4 (%3) with file system %1." )
+    return tr( "Create new %2MiB partition on %4 (%3) with file system %1." )
             .arg( m_partition->fileSystem().name() )
             .arg( CalamaresUtils::BytesToMiB( m_partition->capacity() ) )
             .arg( m_device->name() )
@@ -52,7 +52,7 @@ CreatePartitionJob::prettyName() const
 QString
 CreatePartitionJob::prettyDescription() const
 {
-    return tr( "Create new <strong>%2MB</strong> partition on <strong>%4</strong> "
+    return tr( "Create new <strong>%2MiB</strong> partition on <strong>%4</strong> "
                "(%3) with file system <strong>%1</strong>." )
             .arg( m_partition->fileSystem().name() )
             .arg( CalamaresUtils::BytesToMiB( m_partition->capacity() ) )
