@@ -1,4 +1,4 @@
-/* === This file is part of Calamares - <http://github.com/calamares> ===
+/* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
  *   Copyright 2015, Teo Mrnjavac <teo@kde.org>
@@ -20,11 +20,15 @@
 
 #include "jobs/ResizePartitionJob.h"
 
+#include "utils/Units.h"
+
 // KPMcore
 #include <core/device.h>
 #include <ops/resizeoperation.h>
 #include <util/report.h>
 
+using CalamaresUtils::BytesToMiB;
+
 //- ResizePartitionJob ---------------------------------------------------------
 ResizePartitionJob::ResizePartitionJob( Device* device, Partition* partition, qint64 firstSector, qint64 lastSector )
     : PartitionJob( partition )
@@ -48,22 +52,22 @@ ResizePartitionJob::prettyName() const
 QString
 ResizePartitionJob::prettyDescription() const
 {
-    return tr( "Resize <strong>%2MB</strong> partition <strong>%1</strong> to "
-               "<strong>%3MB</strong>." )
+    return tr( "Resize <strong>%2MiB</strong> partition <strong>%1</strong> to "
+               "<strong>%3MiB</strong>." )
             .arg( partition()->partitionPath() )
-            .arg( ( m_oldLastSector - m_oldFirstSector + 1 ) * partition()->sectorSize() / 1024 / 1024 )
-            .arg( ( m_newLastSector - m_newFirstSector + 1 ) * partition()->sectorSize() / 1024 / 1024 );
+            .arg( ( BytesToMiB( m_oldLastSector - m_oldFirstSector + 1 ) * partition()->sectorSize() ) )
+            .arg( ( BytesToMiB( m_newLastSector - m_newFirstSector + 1 ) * partition()->sectorSize() ) );
 }
 
 
 QString
 ResizePartitionJob::prettyStatusMessage() const
 {
-    return tr( "Resizing %2MB partition %1 to "
-               "%3MB." )
+    return tr( "Resizing %2MiB partition %1 to "
+               "%3MiB." )
             .arg( partition()->partitionPath() )
-            .arg( ( m_oldLastSector - m_oldFirstSector + 1 ) * partition()->sectorSize() / 1024 / 1024 )
-            .arg( ( m_newLastSector - m_newFirstSector + 1 ) * partition()->sectorSize() / 1024 / 1024 );
+            .arg( ( BytesToMiB( m_oldLastSector - m_oldFirstSector + 1 ) * partition()->sectorSize() ) )
+            .arg( ( BytesToMiB( m_newLastSector - m_newFirstSector + 1 ) * partition()->sectorSize() ) );
 }
 
 
@@ -76,7 +80,7 @@ ResizePartitionJob::exec()
     m_partition->setLastSector( m_oldLastSector );
     ResizeOperation op(*m_device, *m_partition, m_newFirstSector, m_newLastSector);
     op.setStatus(Operation::StatusRunning);
-    connect(&op, &Operation::progress, [&](int percent) { emit progress(percent / 100.0); } );
+    connect(&op, &Operation::progress, this, &ResizePartitionJob::iprogress );
 
     QString errorMessage = tr( "The installer failed to resize partition %1 on disk '%2'." )
                        .arg( m_partition->partitionPath() )
