@@ -1,7 +1,8 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017, 2019, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2019, Collabora Ltd <arnaud.ferraris@collabora.com>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,11 +22,14 @@
 
 #include "SummaryViewStep.h"
 
+#include "Branding.h"
 #include "ExecutionViewStep.h"
-#include "utils/Retranslator.h"
+#include "Settings.h"
+#include "ViewManager.h"
+
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Logger.h"
-#include "ViewManager.h"
+#include "utils/Retranslator.h"
 
 #include <QBoxLayout>
 #include <QLabel>
@@ -39,21 +43,31 @@ SummaryPage::SummaryPage( const SummaryViewStep* thisViewStep, QWidget* parent )
     , m_contentWidget( nullptr )
     , m_scrollArea( new QScrollArea( this ) )
 {
-    Q_UNUSED( parent );
+    Q_UNUSED( parent )
+
+    this->setObjectName("summaryStep");
+
     Q_ASSERT( m_thisViewStep );
     QVBoxLayout* layout = new QVBoxLayout( this );
     layout->setContentsMargins( 0, 0, 0, 0 );
 
     QLabel* headerLabel = new QLabel( this );
     CALAMARES_RETRANSLATE(
-        headerLabel->setText( tr( "This is an overview of what will happen once you start "
-                                  "the install procedure." ) );
+        if ( Calamares::Settings::instance()->isSetupMode() )
+            headerLabel->setText( tr( "This is an overview of what will happen once you start "
+                                      "the setup procedure." ) );
+        else
+            headerLabel->setText( tr( "This is an overview of what will happen once you start "
+                                      "the install procedure." ) );
     )
     layout->addWidget( headerLabel );
     layout->addWidget( m_scrollArea );
     m_scrollArea->setWidgetResizable( true );
     m_scrollArea->setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
-    m_scrollArea->setVerticalScrollBarPolicy( Qt::ScrollBarAsNeeded );
+    // If Calamares will grow, then only show scrollbar when it's needed
+    // (e.g. when the screen is full).
+    m_scrollArea->setVerticalScrollBarPolicy(
+        Calamares::Branding::instance()->windowExpands() ? Qt::ScrollBarAsNeeded : Qt::ScrollBarAlwaysOn );
     m_scrollArea->setFrameStyle( QFrame::NoFrame );
     m_scrollArea->setContentsMargins( 0, 0, 0, 0 );
 }
@@ -170,7 +184,7 @@ SummaryPage::createBodyLabel( const QString& text ) const
     QLabel* label = new QLabel;
     label->setMargin( CalamaresUtils::defaultFontHeight() / 2 );
     QPalette pal( palette() );
-    pal.setColor( QPalette::Background, palette().background().color().lighter( 108 ) );
+    pal.setColor( QPalette::Background, palette().window().color().lighter( 108 ) );
     label->setAutoFillBackground( true );
     label->setPalette( pal );
     label->setText( text );
